import React from 'react';
import { connect } from 'dva';
import { Button, Table, Popconfirm } from 'antd';
import styles from './list.less';
import { thisPush } from '../../../../services/route';

class List extends React.Component {
  state = {
    values: '',
  }
  componentDidMount() {
    this.props.dispatch({ type: 'appInfo/getAppInfo', payload: { name: '' } });
  }
  onDelete = (record) => {
    const name = record.name;
    this.props.dispatch({ type: 'appInfo/delAppInfo', payload: { name } });
  };
  onEdit = (record) => {
    console.log(record);
    thisPush(this, { pathname: '../edit', state: { value: record } });
  };
  onDeploy = (record) => {
    thisPush(this, { pathname: '../deploy', state: { value: record } });
    this.props.dispatch({ type: 'appInfo/saveRecord', payload: { record } });
  };
  onClick = () => {
    thisPush(this, { pathname: '../add', state: { value: '' } });
  };
  makeColumns() {
    const columns = [{
      title: '创建时间',
      dataIndex: 'createTime',
    }, {
      title: '名称',
      dataIndex: 'name',
    }, {
      title: '包名',
      dataIndex: 'packageName',
    }, {
      title: '描述',
      dataIndex: 'description',
    }, {
      title: '操作',
      dataIndex: 'operation',
      render: (text, record, index) => (
        <span>
          <span className="ant-divider" />
          <a onClick={() => this.onEdit(record, index)}>Edit</a>
          <span className="ant-divider" />
          <Popconfirm title="确定删除？" okText="Yes" cancelText="No"onConfirm={() => this.onDelete(record, index)}>
            <a>Delete</a>
          </Popconfirm>
          <span className="ant-divider" />
          <a onClick={() => this.onDeploy(record, index)}>deploy</a>
        </span>
      ),
    }];
    return columns;
  }
  render() {
    const { allAppInfo } = this.props.appInfo;
    const data = allAppInfo.map(({ createTime, name, packageName, description }) => {
      const date = (new Date(createTime)).toLocaleString();
      const info = {
        key: createTime,
        createTime: date,
        name,
        packageName,
        description,
      };
      return info;
    });
    return (
      <div className={styles.wrapper}>
        <div className={styles.container}>
          <div className={styles.divBtn}>
            <Button type="primary" icon="plus" onClick={this.onClick}>添加</Button>
          </div>
          <div className={styles.divTable}>
            <Table columns={this.makeColumns()} dataSource={data} />
          </div>
        </div>
      </div>
    );
  }
}

export default connect(({ appInfo, loading }) => ({ appInfo, loading }))(List);

